@php

    /**
     * @param   array $block The block settings and attributes.
     * @param   string $content The block inner HTML (empty).
     * @param   bool $is_preview True during AJAX preview.
     * @param   (int|string) $post_id The post ID this block is saved to.
     */

    $id = 'muy-events-list' . $block['id'];
    if (!empty($block['anchor'])) {
        $id = $block['anchor'];
    }

    $className = 'muy-' . $block['slug'];
    if (!empty($block['className'])) {
        $className .= ' container ' . $block['className'];
    }
    if (!empty($block['align'])) {
        $className .= ' align' . $block['align'];
    }


    $month_to_show = null;
    $events_select_type = get_field('events_select_type');
    $events_print_category = get_field('events_print_category');
    $events_teaser_image_height = get_field('events_teaser_image_height', 'muy-height-md');
    $events_per_row = get_field('events_per_row');
    // $products = '';
    $selected = get_field('selected_events');
    // $n = get_field('products_number');
    $title_color = get_field('title_color');
    $excerpt_color = get_field('excerpt_color');
    $cta_color = get_field('cta_color');
    $date_style = get_field('date_style');
    $date_bkg_color = get_field('date_bkg_color');
    $date_text_color = get_field('date_text_color');
    

    switch ($events_per_row) {
        case '1':
            $column_class = 'w-full teaser-single-column';
            break;

        case '2':
            $column_class = 'w-full md__w-1/2 teaser-multi-column';
            break;

        case '4':
            $column_class = 'w-full md__w-1/2 lg__w-1/4 teaser-multi-column';
            break;

        default:
            $column_class = 'w-full md__w-1/2 lg__w-1/3 teaser-multi-column';

            break;
    }

    $args = [
        'start_date' => 'now',
        'posts_per_page'=>-1,
        'meta_key' => '_EventStartDate',
        'order' => 'ASC',
    ];

    if ($events_print_category) {
        $args['tax_query'] = [
            [
                'taxonomy' => 'tribe_events_cat',
                'field' => 'term_id',
                'terms' => $events_print_category
            ]
        ];
    }

    if ($events_select_type == 'all') { // Aggiunto per gestire eventi futuri e passati
        $events_all = tribe_get_events(array(
            'posts_per_page'=>-1,
            'eventDisplay'=>'all',
        ));

        $events = $events_all;
    } elseif ($events_select_type == 'past') {
        $events = tribe_get_events(array(
            'posts_per_page'=>-1,
            'eventDisplay'=>'past',
        ));
    } else {
        $events = tribe_get_events($args);
    }


    if ($selected) {
        $events = $selected;
    }
    

@endphp

<div id="{{ esc_attr($id) }}" class="{{ esc_attr($className) }}">
  @if ($selected)
  <div class="container">
    <div class="-mx-4 row mb-24">
      @foreach ($events as $event)
      <div class="{{ $column_class }}">
          @include('partials.teaser-event', [
              'titleColor' => $title_color,
              'excerptColor' => $excerpt_color,
              'catColor' => $cta_color,
          ])
      </div>
      @endforeach
    </div>
  </div>
  </div>
  @else
  @foreach ($events as $event)
  @php
      $month = tribe_get_start_date($event, false, 'F Y');
      $show_header = $month != $month_to_show;
      $month_to_show = $month;
  @endphp
  @if ($show_header && !$loop->first)
    </div>
  @endif

  @if ($show_header)
      <h4 class="section-title mb-10 font-bold" style="font-size:40px;">{{ $month }}</h4> <!-- Aggiunto titolo per il mese -->
      <div class="container px-0">
          <div class="-mx-4 row mb-24">
  @endif

  <div class="{{ $column_class }}">
      @include('partials.teaser-event', [
          'titleColor' => $title_color,
          'excerptColor' => $excerpt_color,
          'catColor' => $cta_color,
          'dateStyle' => $date_style,
          'dateBkgColor' => $date_bkg_color,
          'dateTextColor' => $date_text_color,
      ])
  </div>

  {{-- <div class="event-teaser">
        <h5>{{$event->post_title}}</h5>
        <h6>{{ tribe_get_start_date($event, false, 'd F Y') }}</h6>
        <figure class="max-w-8">
          {!!get_the_post_thumbnail($event->ID)!!}
        </figure>
      </div> --}}

  @if ($loop->last)
      </div>
      </div>
  @endif
@endforeach    
  @endif
        </div>
